pub enum PrLaneApprovalState {
ClassApproved,
ClassNotApproved,
}Expand description
Approval state for the autonomous PR lane.
Variants
ClassApproved
The task class is explicitly approved for autonomous PR creation.
ClassNotApproved
The task class is not approved for autonomous PR creation.